@@ -977,15 +977,27 @@ is ignored."
    (or sequences (denote-sequence-get-all-sequences))
    #'denote-sequence-p :require-match nil 'denote-sequence-history))
 
-(defun denote-sequence-depth-prompt (&optional prompt-text)
+(defvar denote-sequence-depth-history nil
+  "Minibuffer history of `denote-sequence-depth-prompt'.")
+
+(defun denote-sequence-depth-prompt (&optional prompt-text default-value)
   "Prompt for the depth of a sequence.
-With optional PROMPT-TEXT use it instead of the generic one."
-  (read-number
-   (or prompt-text
-       (format "Get sequences up to this depth %s: "
-               (if (eq denote-sequence-scheme 'alphanumeric)
-                   "(e.g. `1a2' is `3' levels of depth)"
-                 "(e.g. `1=1=2' is `3' levels of depth)")))))
+With optional PROMPT-TEXT use it instead of the generic one.
+
+With optional DEFAULT-VALUE use it as the default minibuffer value, else
+use the `car' of `denote-sequence-depth-history', if any."
+  (let* ((default (or default-value (car denote-sequence-depth-history)))
+         (default-number (if (stringp default)
+                             (string-to-number default)
+                           default)))
+    (read-number
+     (or prompt-text
+         (format "Get sequences up to this depth %s: "
+                 (if (eq denote-sequence-scheme 'alphanumeric)
+                     "(e.g. `1a2' is `3' levels of depth)"
+                   "(e.g. `1=1=2' is `3' levels of depth)")))
+     default-number
+     'denote-sequence-depth-history)))
 
 (defun denote-sequence--get-dired-buffer-name (&optional prefix depth)
   "Return a string for `denote-sequence-dired' buffer.
@@ -1036,7 +1048,7 @@ For a more specialised case, see `denote-sequence-find-relatives-dired'."
                                 files-sorted)))))
     (if-let* ((directory (if relative-p ; see comment in `denote-file-prompt'
                              (car (denote-directories))
-                           (denote-sort-dired--find-common-directory (denote-directories))))
+                           (denote-directories-get-common-root)))
               (files (funcall files-fn))
               (dired-name (format-message "prefix `%s'; depth `%s'" (or prefix "ALL") (or depth "ALL")))
               (buffer-name dired-name))
