@@ -1,4 +1,4 @@
-;;; denote-test.el --- Unit tests for denote-sequence.el -*- lexical-binding: t -*-
+;;; denote-sequence-test.el --- Unit tests for denote-sequence.el -*- lexical-binding: t -*-
 
 ;; Copyright (C) 2023-2025  Free Software Foundation, Inc.
 
@@ -49,7 +49,7 @@ Use the function `denote-sequence-get-new' for child and sibling with
 the numeric and alphanumeric `denote-sequence-scheme', as well as the
 function `denote-sequence-get-relative'."
   (let* ((denote-sequence-scheme 'numeric)
-         (denote-directory (expand-file-name "denote-test" temporary-file-directory))
+         (denote-directory (expand-file-name "denote-sequence-test" temporary-file-directory))
          (files
           (mapcar
            (lambda (file)
@@ -129,7 +129,7 @@ function `denote-sequence-get-relative'."
                             "20241230T075023==1=1=2--test__testing.txt")))
 
   (let* ((denote-sequence-scheme 'alphanumeric)
-         (denote-directory (expand-file-name "denote-test" temporary-file-directory))
+         (denote-directory (expand-file-name "denote-sequence-test" temporary-file-directory))
          (files
           (mapcar
            (lambda (file)
@@ -224,18 +224,43 @@ function `denote-sequence-get-relative'."
   (should-error (denote-sequence-make-conversion "111=a" :string-is-sequence))
   (should-error (denote-sequence-make-conversion "a1" :string-is-sequence)))
 
-(ert-deftest dst-denote-sequence-increment ()
-  "Test that `denote-sequence-increment' works with numbers and letters."
-  (should (string= (denote-sequence-increment "z") "za"))
-  (should (string= (denote-sequence-increment "ab") "ac"))
-  (should (string= (denote-sequence-increment "az") "aza"))
-  (should (string= (denote-sequence-increment "bbcz") "bbcza"))
-  (should (string= (denote-sequence-increment "1") "2"))
-  (should (string= (denote-sequence-increment "10") "11"))
-  (should-error (denote-sequence-increment "1=a")))
+(ert-deftest dst-denote-sequence-increment-partial ()
+  "Test that `denote-sequence-increment-partial' does the right thing."
+  (should (string= (denote-sequence-increment-partial "1") "2"))
+  (should (string= (denote-sequence-increment-partial "a") "b"))
+  (should (string= (denote-sequence-increment-partial "z") "za"))
+  (should (string= (denote-sequence-increment-partial "zz") "zza"))
+  (should (string= (denote-sequence-increment-partial "bbcz") "bbcza"))
+  (should-error (denote-sequence-increment-partial "1=1"))
+  (should-error (denote-sequence-increment-partial "1a")))
 
-(provide 'denote-test)
-;;; denote-test.el ends here
+(ert-deftest dst-denote-sequence-decrement-partial ()
+  "Test that `denote-sequence-decrement-partial' does the right thing."
+  (should (null (denote-sequence-decrement-partial "1")))
+  (should (null (denote-sequence-decrement-partial "a")))
+  (should (string= (denote-sequence-decrement-partial "2") "1"))
+  (should (string= (denote-sequence-decrement-partial "b") "a"))
+  (should (string= (denote-sequence-decrement-partial "za") "z"))
+  (should (string= (denote-sequence-decrement-partial "zza") "zz"))
+  (should (string= (denote-sequence-decrement-partial "bbcza") "bbcz"))
+  (should-error (denote-sequence-decrement-partial "1a")))
+
+(ert-deftest dst-denote-sequence--infer-sibling ()
+  "Test that `denote-sequence--infer-sibling' returns the correct result."
+  (should (string= (denote-sequence--infer-sibling "1" 'next) "2"))
+  (should (string= (denote-sequence--infer-sibling "1a" 'next) "1b"))
+  (should (string= (denote-sequence--infer-sibling "1z" 'next) "1za"))
+  (should (string= (denote-sequence--infer-sibling "1=1" 'next) "1=2"))
+  (should (string= (denote-sequence--infer-sibling "2" 'previous) "1"))
+  (should (string= (denote-sequence--infer-sibling "1b" 'previous) "1a"))
+  (should (string= (denote-sequence--infer-sibling "1za" 'previous) "1z"))
+  (should (string= (denote-sequence--infer-sibling "1=2" 'previous) "1=1"))
+  (should (null (denote-sequence--infer-sibling "1" 'previous)))
+  (should (null (denote-sequence--infer-sibling "1=1" 'previous)))
+  (should (null (denote-sequence--infer-sibling "1a" 'previous))))
+
+(provide 'denote-sequence-test)
+;;; denote-sequence-test.el ends here
 
 ;; Local Variables:
 ;; read-symbol-shorthands: (("dst" . "denote-sequence-test-"))
